@@ -14,4 +14,4 @@ class InvalidSimpleArchive(InvalidArchive):
 
 
 class NotADataFile(Exception):
-    """The file doesn't exists or is not a data file."""
+    """The file doesn't exist or is not a data file."""
