@@ -13,12 +13,12 @@ class TestDataFileDescriptor(unittest.TestCase):
     """Unit tests for DataFileDescriptor class."""
 
     def test_init_from_file(self):
-        """ Ensure a DataFileDescriptor can be constructed directly from a CSV file.
+        """Ensure a DataFileDescriptor can be constructed directly from a CSV file.
 
         This is necessary for archives sans metafile.
         """
-        with zipfile.ZipFile(sample_data_path('dwca-simple-csv.zip'), 'r') as archive:
-            datafile_path = archive.extract('0008333-160118175350007.csv')
+        with zipfile.ZipFile(sample_data_path("dwca-simple-csv.zip"), "r") as archive:
+            datafile_path = archive.extract("0008333-160118175350007.csv")
 
             d = DataFileDescriptor.make_from_file(datafile_path)
             # Check basic metadata with the file
@@ -26,8 +26,8 @@ class TestDataFileDescriptor(unittest.TestCase):
             assert d.represents_corefile
             assert not d.represents_extension
             assert d.type is None
-            assert d.file_location == '0008333-160118175350007.csv'
-            assert d.file_encoding == 'utf-8'
+            assert d.file_location == "0008333-160118175350007.csv"
+            assert d.file_encoding == "utf-8"
             assert d.lines_terminated_by == "\n"
             assert d.fields_terminated_by == "\t"
             assert d.fields_enclosed_by == '"'
@@ -35,8 +35,10 @@ class TestDataFileDescriptor(unittest.TestCase):
             # Some checks on fields...
 
             # A few fields are checked
-            expected_fields = ({'default': None, 'index': 0, 'term': 'gbifid'},
-                               {'default': None, 'index': 3, 'term': 'kingdom'})
+            expected_fields = (
+                {"default": None, "index": 0, "term": "gbifid"},
+                {"default": None, "index": 3, "term": "kingdom"},
+            )
 
             for ef in expected_fields:
                 assert ef in d.fields
@@ -46,7 +48,7 @@ class TestDataFileDescriptor(unittest.TestCase):
 
             # No fields should have a default value (there's no metafile to set it!)
             for f in d.fields:
-                assert f['default'] is None
+                assert f["default"] is None
 
             # Ensure .terms is also set:
             assert len(d.terms) == 42
@@ -67,7 +69,9 @@ class TestDataFileDescriptor(unittest.TestCase):
         </core>
         """
 
-        core_descriptor = DataFileDescriptor.make_from_metafile_section(ET.fromstring(metaxml_section))
+        core_descriptor = DataFileDescriptor.make_from_metafile_section(
+            ET.fromstring(metaxml_section)
+        )
 
         assert core_descriptor.lines_to_ignore == 0
 
@@ -83,7 +87,9 @@ class TestDataFileDescriptor(unittest.TestCase):
         </core>
         """
 
-        core_descriptor = DataFileDescriptor.make_from_metafile_section(ET.fromstring(metaxml_section))
+        core_descriptor = DataFileDescriptor.make_from_metafile_section(
+            ET.fromstring(metaxml_section)
+        )
 
         assert core_descriptor.lines_to_ignore == 1
 
@@ -99,7 +105,9 @@ class TestDataFileDescriptor(unittest.TestCase):
         </core>
         """
 
-        core_descriptor = DataFileDescriptor.make_from_metafile_section(ET.fromstring(metaxml_section))
+        core_descriptor = DataFileDescriptor.make_from_metafile_section(
+            ET.fromstring(metaxml_section)
+        )
 
         assert core_descriptor.lines_to_ignore == 0
 
@@ -119,7 +127,9 @@ class TestDataFileDescriptor(unittest.TestCase):
         </core>
         """
 
-        core_descriptor = DataFileDescriptor.make_from_metafile_section(ET.fromstring(metaxml_section))
+        core_descriptor = DataFileDescriptor.make_from_metafile_section(
+            ET.fromstring(metaxml_section)
+        )
 
         assert core_descriptor.file_location == "occurrence.txt"
         assert core_descriptor.file_encoding == "utf-8"
@@ -143,17 +153,22 @@ class TestDataFileDescriptor(unittest.TestCase):
         </core>
         """
 
-        core_descriptor = DataFileDescriptor.make_from_metafile_section(ET.fromstring(metaxml_section))
+        core_descriptor = DataFileDescriptor.make_from_metafile_section(
+            ET.fromstring(metaxml_section)
+        )
 
         # .fields is supposed to return a list of dicts like those
         expected_fields = (
-            {'term': 'http://rs.tdwg.org/dwc/terms/country',
-             'index': None,
-             'default': 'Belgium'},
-
-            {'term': 'http://rs.tdwg.org/dwc/terms/scientificName',
-             'index': 1,
-             'default': None}
+            {
+                "term": "http://rs.tdwg.org/dwc/terms/country",
+                "index": None,
+                "default": "Belgium",
+            },
+            {
+                "term": "http://rs.tdwg.org/dwc/terms/scientificName",
+                "index": 1,
+                "default": None,
+            },
         )
 
         for ef in expected_fields:
@@ -162,44 +177,56 @@ class TestDataFileDescriptor(unittest.TestCase):
         assert len(core_descriptor.fields) == 5
 
     def test_headers_simplecases(self):
-        with DwCAReader(sample_data_path('dwca-2extensions.zip')) as dwca:
+        with DwCAReader(sample_data_path("dwca-2extensions.zip")) as dwca:
             descriptor = dwca.descriptor
 
             # With core file...
-            expected_headers_core = ['id',
-                                     'http://rs.tdwg.org/dwc/terms/order',
-                                     'http://rs.tdwg.org/dwc/terms/class',
-                                     'http://rs.tdwg.org/dwc/terms/kingdom',
-                                     'http://rs.tdwg.org/dwc/terms/phylum',
-                                     'http://rs.tdwg.org/dwc/terms/genus',
-                                     'http://rs.tdwg.org/dwc/terms/family']
+            expected_headers_core = [
+                "id",
+                "http://rs.tdwg.org/dwc/terms/order",
+                "http://rs.tdwg.org/dwc/terms/class",
+                "http://rs.tdwg.org/dwc/terms/kingdom",
+                "http://rs.tdwg.org/dwc/terms/phylum",
+                "http://rs.tdwg.org/dwc/terms/genus",
+                "http://rs.tdwg.org/dwc/terms/family",
+            ]
 
             assert descriptor.core.headers == expected_headers_core
 
             # And with a first extension...
-            expected_headers_description_ext = ['coreid',
-                                                'http://purl.org/dc/terms/type',
-                                                'http://purl.org/dc/terms/language',
-                                                'http://purl.org/dc/terms/description']
+            expected_headers_description_ext = [
+                "coreid",
+                "http://purl.org/dc/terms/type",
+                "http://purl.org/dc/terms/language",
+                "http://purl.org/dc/terms/description",
+            ]
 
-            desc_ext_descriptor = next(d for d in dwca.descriptor.extensions
-                                       if d.type == 'http://rs.gbif.org/terms/1.0/Description')
+            desc_ext_descriptor = next(
+                d
+                for d in dwca.descriptor.extensions
+                if d.type == "http://rs.gbif.org/terms/1.0/Description"
+            )
 
             assert desc_ext_descriptor.headers == expected_headers_description_ext
 
             # And another one
-            expected_headers_vernacular_ext = ['coreid',
-                                               'http://rs.tdwg.org/dwc/terms/countryCode',
-                                               'http://purl.org/dc/terms/language',
-                                               'http://rs.tdwg.org/dwc/terms/vernacularName']
+            expected_headers_vernacular_ext = [
+                "coreid",
+                "http://rs.tdwg.org/dwc/terms/countryCode",
+                "http://purl.org/dc/terms/language",
+                "http://rs.tdwg.org/dwc/terms/vernacularName",
+            ]
 
-            vern_ext_descriptor = next(d for d in dwca.descriptor.extensions
-                                       if d.type == 'http://rs.gbif.org/terms/1.0/VernacularName')
+            vern_ext_descriptor = next(
+                d
+                for d in dwca.descriptor.extensions
+                if d.type == "http://rs.gbif.org/terms/1.0/VernacularName"
+            )
 
             assert vern_ext_descriptor.headers == expected_headers_vernacular_ext
 
     def test_headers_defaultvalue(self):
-        """ Ensure headers work properly when confronted to default values (w/o column in file)"""
+        """Ensure headers work properly when confronted to default values (w/o column in file)"""
         metaxml_section = """
         <core encoding="utf-8" fieldsTerminatedBy="\t" linesTerminatedBy="\n" fieldsEnclosedBy=""
         ignoreHeaderLines="0" rowType="http://rs.tdwg.org/dwc/terms/Occurrence">
@@ -215,13 +242,17 @@ class TestDataFileDescriptor(unittest.TestCase):
         </core>
         """
 
-        core_descriptor = DataFileDescriptor.make_from_metafile_section(ET.fromstring(metaxml_section))
+        core_descriptor = DataFileDescriptor.make_from_metafile_section(
+            ET.fromstring(metaxml_section)
+        )
 
-        expected_headers_core = ['id',
-                                 'http://rs.tdwg.org/dwc/terms/scientificName',
-                                 'http://rs.tdwg.org/dwc/terms/basisOfRecord',
-                                 'http://rs.tdwg.org/dwc/terms/family',
-                                 'http://rs.tdwg.org/dwc/terms/locality']
+        expected_headers_core = [
+            "id",
+            "http://rs.tdwg.org/dwc/terms/scientificName",
+            "http://rs.tdwg.org/dwc/terms/basisOfRecord",
+            "http://rs.tdwg.org/dwc/terms/family",
+            "http://rs.tdwg.org/dwc/terms/locality",
+        ]
 
         assert core_descriptor.headers == expected_headers_core
 
@@ -241,9 +272,17 @@ class TestDataFileDescriptor(unittest.TestCase):
                 </core>
                 """
 
-        core_descriptor = DataFileDescriptor.make_from_metafile_section(ET.fromstring(metaxml_section))
+        core_descriptor = DataFileDescriptor.make_from_metafile_section(
+            ET.fromstring(metaxml_section)
+        )
 
-        expected_short_headers_core = ['id', 'scientificName', 'basisOfRecord', 'family', 'locality']
+        expected_short_headers_core = [
+            "id",
+            "scientificName",
+            "basisOfRecord",
+            "family",
+            "locality",
+        ]
 
         assert core_descriptor.short_headers == expected_short_headers_core
 
@@ -263,24 +302,28 @@ class TestDataFileDescriptor(unittest.TestCase):
             <field index="5" term="http://rs.tdwg.org/dwc/terms/genus"/>
         </core>
         """
-        core_descriptor = DataFileDescriptor.make_from_metafile_section(ET.fromstring(metaxml_section))
+        core_descriptor = DataFileDescriptor.make_from_metafile_section(
+            ET.fromstring(metaxml_section)
+        )
 
-        expected_headers_core = ['id',
-                                 'http://rs.tdwg.org/dwc/terms/order',
-                                 'http://rs.tdwg.org/dwc/terms/class',
-                                 'http://rs.tdwg.org/dwc/terms/kingdom',
-                                 'http://rs.tdwg.org/dwc/terms/phylum',
-                                 'http://rs.tdwg.org/dwc/terms/genus',
-                                 'http://rs.tdwg.org/dwc/terms/family']
+        expected_headers_core = [
+            "id",
+            "http://rs.tdwg.org/dwc/terms/order",
+            "http://rs.tdwg.org/dwc/terms/class",
+            "http://rs.tdwg.org/dwc/terms/kingdom",
+            "http://rs.tdwg.org/dwc/terms/phylum",
+            "http://rs.tdwg.org/dwc/terms/genus",
+            "http://rs.tdwg.org/dwc/terms/family",
+        ]
 
         assert core_descriptor.headers == expected_headers_core
 
     def test_exposes_raw_element_tag(self):
-        with DwCAReader(sample_data_path('dwca-simple-test-archive.zip')) as dwca:
+        with DwCAReader(sample_data_path("dwca-simple-test-archive.zip")) as dwca:
             assert isinstance(dwca.descriptor.core.raw_element, ET.Element)
 
     def test_content_raw_element_tag(self):
-        """ Test the content of raw_element seems decent. """
+        """Test the content of raw_element seems decent."""
         ext_section = """
         <extension encoding="utf-8" fieldsTerminatedBy="\t" linesTerminatedBy="\n"
         fieldsEnclosedBy="" ignoreHeaderLines="1" rowType="http://rs.gbif.org/terms/1.0/Description">
@@ -292,15 +335,17 @@ class TestDataFileDescriptor(unittest.TestCase):
         </extension>
         """
 
-        ext_descriptor = DataFileDescriptor.make_from_metafile_section(ET.fromstring(ext_section))
+        ext_descriptor = DataFileDescriptor.make_from_metafile_section(
+            ET.fromstring(ext_section)
+        )
 
-        assert ext_descriptor.raw_element.tag == 'extension'
-        assert ext_descriptor.raw_element.get('encoding') == 'utf-8'
-        assert len(ext_descriptor.raw_element.findall('field')) == 3
+        assert ext_descriptor.raw_element.tag == "extension"
+        assert ext_descriptor.raw_element.get("encoding") == "utf-8"
+        assert len(ext_descriptor.raw_element.findall("field")) == 3
 
     def test_tell_if_represents_core(self):
         # 1. Test with core
-        with DwCAReader(sample_data_path('dwca-simple-test-archive.zip')) as dwca:
+        with DwCAReader(sample_data_path("dwca-simple-test-archive.zip")) as dwca:
             core_descriptor = dwca.descriptor.core
             assert core_descriptor.represents_corefile
             assert not core_descriptor.represents_extension
@@ -317,7 +362,9 @@ class TestDataFileDescriptor(unittest.TestCase):
         """
 
         # 2. And with extension
-        ext_descriptor = DataFileDescriptor.make_from_metafile_section(ET.fromstring(ext_section))
+        ext_descriptor = DataFileDescriptor.make_from_metafile_section(
+            ET.fromstring(ext_section)
+        )
         assert not ext_descriptor.represents_corefile
         assert ext_descriptor.represents_extension
 
@@ -332,7 +379,9 @@ class TestDataFileDescriptor(unittest.TestCase):
         </extension>
         """
 
-        ext_descriptor = DataFileDescriptor.make_from_metafile_section(ET.fromstring(ext_section))
+        ext_descriptor = DataFileDescriptor.make_from_metafile_section(
+            ET.fromstring(ext_section)
+        )
 
         assert ext_descriptor.coreid_index == 0
 
@@ -355,7 +404,9 @@ class TestDataFileDescriptor(unittest.TestCase):
         </core>
         """
 
-        core_descriptor = DataFileDescriptor.make_from_metafile_section(ET.fromstring(metaxml_section))
+        core_descriptor = DataFileDescriptor.make_from_metafile_section(
+            ET.fromstring(metaxml_section)
+        )
 
         assert core_descriptor.id_index == 0
 
@@ -365,15 +416,15 @@ class TestDataFileDescriptor(unittest.TestCase):
     def test_exposes_core_type(self):
         """Test that it exposes the Archive Core Type as type"""
 
-        with DwCAReader(sample_data_path('dwca-simple-test-archive.zip')) as dwca:
+        with DwCAReader(sample_data_path("dwca-simple-test-archive.zip")) as dwca:
             coredescriptor = dwca.descriptor.core
             # dwca-simple-test-archive.zip should be of Occurrence type
-            assert coredescriptor.type == 'http://rs.tdwg.org/dwc/terms/Occurrence'
+            assert coredescriptor.type == "http://rs.tdwg.org/dwc/terms/Occurrence"
             # Check that shortcuts also work
-            assert coredescriptor.type == qn('Occurrence')
+            assert coredescriptor.type == qn("Occurrence")
 
     def test_exposes_core_terms(self):
-        with DwCAReader(sample_data_path('dwca-star-test-archive.zip')) as star_dwca:
+        with DwCAReader(sample_data_path("dwca-star-test-archive.zip")) as star_dwca:
             # The Core file contains the following rows
             # <field index="1" term="http://rs.tdwg.org/dwc/terms/family"/>
             # <field index="2" term="http://rs.tdwg.org/dwc/terms/phylum"/>
@@ -390,12 +441,16 @@ class TestDataFileDescriptor(unittest.TestCase):
             assert 6 == len(descriptor.core.terms)
 
             # Assert correct content (should be a set, so unordered)
-            fields = set(['http://rs.tdwg.org/dwc/terms/kingdom',
-                          'http://rs.tdwg.org/dwc/terms/order',
-                          'http://rs.tdwg.org/dwc/terms/class',
-                          'http://rs.tdwg.org/dwc/terms/genus',
-                          'http://rs.tdwg.org/dwc/terms/family',
-                          'http://rs.tdwg.org/dwc/terms/phylum'])
+            fields = set(
+                [
+                    "http://rs.tdwg.org/dwc/terms/kingdom",
+                    "http://rs.tdwg.org/dwc/terms/order",
+                    "http://rs.tdwg.org/dwc/terms/class",
+                    "http://rs.tdwg.org/dwc/terms/genus",
+                    "http://rs.tdwg.org/dwc/terms/family",
+                    "http://rs.tdwg.org/dwc/terms/phylum",
+                ]
+            )
 
             assert fields == descriptor.core.terms
 
@@ -404,7 +459,7 @@ class TestArchiveDescriptor(unittest.TestCase):
     """Unit tests for ArchiveDescriptor class."""
 
     def test_exposes_coredescriptor(self):
-        with DwCAReader(sample_data_path('dwca-simple-test-archive.zip')) as basic_dwca:
+        with DwCAReader(sample_data_path("dwca-simple-test-archive.zip")) as basic_dwca:
             assert isinstance(basic_dwca.descriptor.core, DataFileDescriptor)
 
     def test_exposes_extensions_2ext(self):
@@ -444,7 +499,7 @@ class TestArchiveDescriptor(unittest.TestCase):
         """
 
         d = ArchiveDescriptor(all_metaxml)
-        expected_extensions_files = ('description.txt', 'vernacularname.txt')
+        expected_extensions_files = ("description.txt", "vernacularname.txt")
         for ext in d.extensions:
             assert ext.file_location in expected_extensions_files
 
@@ -490,7 +545,7 @@ class TestArchiveDescriptor(unittest.TestCase):
         d = ArchiveDescriptor(all_metaxml, files_to_ignore="description.txt")
 
         assert len(d.extensions) == 1
-        assert d.extensions[0].file_location == 'vernacularname.txt'
+        assert d.extensions[0].file_location == "vernacularname.txt"
 
     def test_exposes_extensions_none(self):
         all_metaxml = """
@@ -511,32 +566,31 @@ class TestArchiveDescriptor(unittest.TestCase):
         assert len(d.extensions) == 0
 
     def test_exposes_extensions_type(self):
-        vn = 'http://rs.gbif.org/terms/1.0/VernacularName'
-        td = 'http://rs.gbif.org/terms/1.0/Description'
+        vn = "http://rs.gbif.org/terms/1.0/VernacularName"
+        td = "http://rs.gbif.org/terms/1.0/Description"
 
         # This archive has no extension, we should get an empty list
-        with DwCAReader(sample_data_path('dwca-simple-test-archive.zip')) as dwca:
+        with DwCAReader(sample_data_path("dwca-simple-test-archive.zip")) as dwca:
             descriptor = dwca.descriptor
             assert [] == descriptor.extensions_type
 
         # This archive only contains the VernacularName extension
-        with DwCAReader(sample_data_path('dwca-star-test-archive.zip')) as dwca:
+        with DwCAReader(sample_data_path("dwca-star-test-archive.zip")) as dwca:
             descriptor = dwca.descriptor
             assert descriptor.extensions_type[0] == vn
             assert 1 == len(descriptor.extensions_type)
 
         # TODO: test with more complex archive
-        with DwCAReader(sample_data_path('dwca-2extensions.zip')) as dwca:
+        with DwCAReader(sample_data_path("dwca-2extensions.zip")) as dwca:
             descriptor = dwca.descriptor
             # 2 extensions are in use : vernacular names and taxon descriptions
             assert 2 == len(descriptor.extensions_type)
             # USe of frozenset to lose ordering
             supposed_extensions = frozenset([vn, td])
-            assert supposed_extensions == \
-                             frozenset(descriptor.extensions_type)
+            assert supposed_extensions == frozenset(descriptor.extensions_type)
 
     def test_exposes_metadata_filename(self):
-        with DwCAReader(sample_data_path('dwca-2extensions.zip')) as dwca:
+        with DwCAReader(sample_data_path("dwca-2extensions.zip")) as dwca:
             descriptor = dwca.descriptor
 
             assert descriptor.metadata_filename == "eml.xml"
